package org.jtheque.core.managers.language;

import org.springframework.context.support.ResourceBundleMessageSource;

import javax.annotation.PostConstruct;

import java.util.*;
import java.text.MessageFormat;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * An editable ressource bundle implementation. 
 * 
 * @author Baptiste Wicht
 */
public final class JThequeResourceBundle extends ResourceBundleMessageSource implements EditableResourceBundle {
    private String[] coreBasenames;

    private final List<String> baseNames = new ArrayList<String>(10);

    /**
     * Init the JTheque ressource bundle. 
     */
    @PostConstruct
    public void init(){
        baseNames.addAll(Arrays.asList(coreBasenames));
        
        refresh();
    }

    @Override
    public void addBasename(String baseName){
        baseNames.add(baseName);

        refresh();
    }

    @Override
    public void removeBasename(String baseName){
        baseNames.remove(baseName);

        refresh();
    }

    @Override
    public void refresh(){
        setBasenames(baseNames.toArray(new String[baseNames.size()]));
    }

    /**
     * Set the basenames of the core. 
     * 
     * @param coreBasenames An array of all the basenames of the core. 
     */
    public void setCoreBasenames(String[] coreBasenames) {
        this.coreBasenames = Arrays.copyOf(coreBasenames, coreBasenames.length);
    }
}
