package org.jtheque.core.managers.module.annotations;

import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Documented;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * An annotation to describe a module. 
 * 
 * @author Baptiste Wicht
 */
@Documented
@Inherited
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.TYPE)
public @interface Module {
    /**
     * Return the name of the module. 
     * 
     * @return The name of the module. 
     */
    String name();
    
    /**
     * Return the author of the module. 
     * 
     * @return The author of the module. 
     */
    String author();
    
    /**
     * Return the description of the module. 
     * 
     * @return The description of the module. 
     */
    String description();
    
    /**
     * Return the version of the module. 
     * 
     * @return The version of the module. 
     */
    String version();
    
    /**
     * Return the needed core version of the module. 
     * 
     * @return The needed core version of the module. 
     */
    String coreVersion();
    
    /**
     * Return the name of the jar file of the module. 
     * 
     * @return The name of the jar file of the module. 
     */
    String jarFile();
}