package org.jtheque.core.managers.module.annotations;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.lang.annotation.Inherited;

/**
 * An annotation who describe a module.
 *
 * @author Baptiste Wicht
 */
@Documented
@Inherited
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.TYPE)
public @interface ModuleDefinition {
    /**
     * The URL of the module.
     *
     * @return URL url of the module.
     */
    String url() default "";

    /**
     * The update URL.
     *
     * @return the update URL.
     */
    String updateURL() default "";

    /**
     * The dependency of the module.
     *
     * @return the dependency of the module.
     */
    String dependency() default "";

    /**
     * The date of the module.
     *
     * @return the date of the module.
     */
    String date() default "";

    /**
     * The message's file URL.
     *
     * @return the message's files URL.
     */
    String messageFileURL() default "";
}