package org.jtheque.core.managers.view.impl.frame;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.core.managers.view.able.IConfigView;
import org.jtheque.core.managers.view.impl.components.LayerTabbedPane;
import org.jtheque.core.managers.view.impl.components.config.ConfigTabComponent;
import org.jtheque.core.managers.view.impl.frame.abstraction.SwingDialogView;
import org.jtheque.core.managers.view.impl.actions.JThequeAction;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.core.managers.view.listeners.ConfigTabEvent;
import org.jtheque.core.managers.view.listeners.ConfigTabListener;
import org.jtheque.core.managers.view.IViewManager;
import org.jtheque.utils.ui.SwingUtils;
import org.jtheque.utils.ui.GridBagUtils;

import javax.annotation.PostConstruct;

import java.awt.Container;
import java.awt.Frame;
import java.util.List;

/**
 * A view for the configuration.
 *
 * @author Baptiste Wicht
 */
public final class ConfigView extends SwingDialogView implements ConfigTabListener, IConfigView {
    private static final long serialVersionUID = -7273750454132893687L;

    private LayerTabbedPane tab;

    private JThequeAction applyChangesAndCloseAction;
    private JThequeAction cancelChangesAction;
    private JThequeAction applyChangesAction;

    /**
     * Construct a new ConfigView.
     *
     * @param frame The parent frame.
     */
    public ConfigView(Frame frame) {
        super(frame);
    }

    @Override
    @PostConstruct
    public void build() {
        setContentPane(buildContentPane());
        setResizable(true);
        setTitleKey("config.view.title");

        pack();
        SwingUtils.centerFrame(this);
    }

    /**
     * Build and return the contentpane.
     *
     * @return The contentpane
     */
    private Container buildContentPane() {
        PanelBuilder builder = new PanelBuilder();

        tab = new LayerTabbedPane();

        for (ConfigTabComponent component : Managers.getManager(IViewManager.class).getConfigTabComponents()) {
            tab.addTab(component.getTitle(), component.getComponent());
        }

        Managers.getManager(IViewManager.class).addConfigTabListener(this);

        builder.add(tab, builder.gbcSet(0,0, GridBagUtils.BOTH));

        builder.addButtonBar(builder.gbcSet(0,1, GridBagUtils.HORIZONTAL),
                applyChangesAndCloseAction, cancelChangesAction, applyChangesAction);

        return builder.getPanel();
    }

    @Override
    public ConfigTabComponent getSelectedPanelConfig() {
        return (ConfigTabComponent) tab.getSelectedComponent();
    }

    @Override
    public void tabAdded(ConfigTabEvent event) {
        tab.addTab(event.getComponent().getTitle(), event.getComponent().getComponent());
    }

    @Override
    public void tabRemoved(ConfigTabEvent event) {
        tab.removeTabAt(tab.indexOfTab(event.getComponent().getTitle()));
    }

    @Override
    protected void validate(List<JThequeError> errors) {
        getSelectedPanelConfig().validate(errors);
    }

    /**
     * Set the action to apply the changes and close the view. This is not for use, this is only for Spring injection. 
     * 
     * @param applyChangesAndCloseAction The action. 
     */
    public void setApplyChangesAndCloseAction(JThequeAction applyChangesAndCloseAction) {
        this.applyChangesAndCloseAction = applyChangesAndCloseAction;
    }

    /**
     * Set the action to cancel the changes. This is not for use, this is only for Spring injection. 
     * 
     * @param cancelChangesAction The action. 
     */
    public void setCancelChangesAction(JThequeAction cancelChangesAction) {
        this.cancelChangesAction = cancelChangesAction;
    }

    /**
     * Set the action to apply the changes. This is not for use, this is only for Spring injection. 
     * 
     * @param applyChangesAction The action. 
     */
    public void setApplyChangesAction(JThequeAction applyChangesAction) {
        this.applyChangesAction = applyChangesAction;
    }
}