package org.jtheque.core.spring.factory;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.log.ILoggingManager;
import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.beans.IBeansManager;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;
import java.lang.reflect.InvocationTargetException;

/**
 * An invocation handler to disable the manager.
 *
 * @author Baptiste Wicht
 */
final class LazyProxyHandler implements InvocationHandler {
    private final String beanName;

    private Object instance;

    /**
     * Construct a new LazyProxyHandler. 
     * 
     * @param beanName The name of the bean. 
     */
    LazyProxyHandler(String beanName) {
        super();

        this.beanName = beanName;
    }

    @Override
    public Object invoke(Object proxy, Method method, Object[] args) throws InvocationTargetException, IllegalAccessException {
        if(instance == null){
            Managers.getManager(ILoggingManager.class).getLogger(getClass()).debug("Init " + beanName + " due to call to " + method.toGenericString());

            instance = Managers.getManager(IBeansManager.class).getBean(beanName);
        }

        return method.invoke(instance, args);
    }
}